Informative
===========

.. toctree::
   :numbered:
   :maxdepth: 1

   value
   Data Managers - Accessing and writing the data on attributes and in dictionaries <datamanager>
   converter
   Terms - Wrappers around sources and vocabularies providing a common interface for choices <term>
   util
   adding
   testing
   Current problems of ObjectWidget <object-caveat>
